==> rubygems_3.2.5.orig.tar.gz: rubygems-3.2.5/bundler/doc/README.md <==
# Docs: Contributing and developing Bundler

_If you're looking for documentation on how to use Bundler: visit [bundler.io](https://bundler.io/), or run `bundle help` from the command line. You may also be interested in [troubleshooting common issues](TROUBLESHOOTING.md) found when using Bundler._

Bundler welcomes contributions from *everyone*. While contributing, please follow the project [code of conduct](https://bundler.io/conduct.html), so that everyone can be included. Maintainers are expected to work together with the community in accordance with [our project policies](POLICIES.md).

If you'd like to help make Bundler better, you totally rock! Thanks for helping us make Bundler better.

## Contributing

* [Overview & getting started](contributing/README.md)
* [How you can help: your first contributions!](contributing/HOW_YOU_CAN_HELP.md)
* [Bug triage](contributing/BUG_TRIAGE.md)
* [Getting help](contributing/GETTING_HELP.md)
* [Filing issues](contributing/ISSUES.md)
* [Community](contributing/COMMUNITY.md)

## Development

* [Overview](development/README.md)
* [Development setup](development/SETUP.md)
* [Submitting pull requests](development/PULL_REQUESTS.md)
* [Adding new features](development/NEW_FEATURES.md)

## Documentation

* [Overview](documentation/README.md)
* [Writing docs for man pages](documentation/WRITING.md)
* [Documentation vision](documentation/VISION.md)

## Maintainers

* [Merging pull requests](playbooks/MERGING_A_PR.md)
* [Releasing Bundler](playbooks/RELEASING.md)

==> rubygems_3.3.5.orig.tar.gz: rubygems-3.3.5/bundler/doc/README.md <==
# Docs: Contributing and developing Bundler

_If you're looking for documentation on how to use Bundler: visit [bundler.io](https://bundler.io/), or run `bundle help` from the command line. You may also be interested in [troubleshooting common issues](TROUBLESHOOTING.md) found when using Bundler._

Bundler welcomes contributions from *everyone*. While contributing, please follow the project [code of conduct](https://bundler.io/conduct.html), so that everyone can be included. Maintainers are expected to work together with the community in accordance with [our project policies](POLICIES.md).

If you'd like to help make Bundler better, you totally rock! Thanks for helping us make Bundler better.

## Contributing

* [Overview & getting started](contributing/README.md)
* [How you can help: your first contributions!](contributing/HOW_YOU_CAN_HELP.md)
* [Bug triage](contributing/BUG_TRIAGE.md)
* [Getting help](contributing/GETTING_HELP.md)
* [Filing issues](https://github.com/rubygems/rubygems/issues/new?labels=Bundler&template=bundler-related-issue.md)
* [Community](contributing/COMMUNITY.md)

## Development

* [Overview](development/README.md)
* [Development setup](development/SETUP.md)
* [Submitting pull requests](development/PULL_REQUESTS.md)
* [Adding new features](development/NEW_FEATURES.md)

## Documentation

* [Overview](documentation/README.md)
* [Writing docs for man pages](documentation/WRITING.md)
* [Documentation vision](documentation/VISION.md)

## Maintainers

* [Merging pull requests](playbooks/MERGING_A_PR.md)
* [Releasing Bundler](playbooks/RELEASING.md)
